Learn R Programming

logger (version 0.4.3)

formatter_cli: Apply cli::cli_text() to format string with cli syntax

Description

Apply cli::cli_text() to format string with cli syntax

Usage

formatter_cli(
  ...,
  .logcall = sys.call(),
  .topcall = sys.call(-1),
  .topenv = parent.frame()
)

Value

character vector

Arguments

...

passed to cli::cli_text() for the text interpolation

.logcall

the logging call being evaluated (useful in formatters and layouts when you want to have access to the raw, unevaluated R expression)

.topcall

R expression from which the logging function was called (useful in formatters and layouts to extract the calling function's name or arguments)

.topenv

original frame of the .topcall calling function where the formatter function will be evaluated and that is used to look up the namespace as well via logger:::top_env_name

See Also

Other log_formatters: formatter_glue(), formatter_glue_or_sprintf(), formatter_glue_safe(), formatter_json(), formatter_logging(), formatter_pander(), formatter_paste(), formatter_sprintf()