| layout_gha | R Documentation |
GitHub Actions can recognise specially formatted output and make these
prominent in the output. The layout_gha() layout will ensure the correct
formatting when running in GitHub Actions.
layout_gha(
level,
msg,
namespace = NA_character_,
.logcall = sys.call(),
.topcall = sys.call(-1),
.topenv = parent.frame(),
.timestamp = Sys.time()
)
level |
log level, see |
msg |
string message |
namespace |
string referring to the |
.logcall |
the logging call being evaluated (useful in formatters and layouts when you want to have access to the raw, unevaluated R expression) |
.topcall |
R expression from which the logging function was called (useful in formatters and layouts to extract the calling function's name or arguments) |
.topenv |
original frame of the |
.timestamp |
The time the logging occured. Defaults to the current time but may be overwritten if the logging is delayed from the time it happend |
character vector
GitHub Actions only recognise the log levels error, warning, notice,
and debug. Because of this, FATAL and ERROR are coerced to error,
SUCCESS and INFO are coerced to notice, and DEBUG and TRACE are
coerced to debug (WARN maps directly to warning).
Other log_layouts:
get_logger_meta_variables(),
layout_blank(),
layout_glue(),
layout_glue_colors(),
layout_glue_generator(),
layout_json(),
layout_json_parser(),
layout_logging(),
layout_simple()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.