| log_errors | R Documentation |
This function sets a hook to trigger log_error() when stop() is called
to log the error messages with the global logger layout and appender.
log_errors(
muffle = getOption("logger_muffle_errors", FALSE),
traceback = FALSE
)
muffle |
if TRUE, the error is not thrown after being logged |
traceback |
if TRUE the error traceback is logged along with the error message |
## Not run:
log_errors()
stop("foobar")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.