| logger-package | R Documentation |
Inspired by the the 'futile.logger' R package and 'logging' Python module, this utility provides a flexible and extensible way of formatting and delivering log messages with low overhead.
Maintainer: Gergely Daróczi daroczig@rapporter.net (ORCID)
Authors:
Hadley Wickham hadley@posit.co (ORCID)
Other contributors:
Jonathan Carroll rpkg@jcarroll.com.au (ORCID) [contributor]
Spare Cores [funder]
System1 [funder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.