powered by
This function sets a hook to trigger log_error() when stop() is called to log the error messages with the global logger layout and appender.
log_error()
stop()
logger
log_errors( muffle = getOption("logger_muffle_errors", FALSE), traceback = FALSE )
if TRUE, the error is not thrown after being logged
if TRUE the error traceback is logged along with the error message
if (FALSE) { log_errors() stop("foobar") }
Run the code above in your browser using DataLab